@@ -1,6 +1,7 @@
 // Upload an image to imagebin.org
 
-var page = new WebPage(), fname;
+var page = require('webpage').create(),
+	fname;
 
 if (phantom.args.length !== 1) {
     console.log('Usage: imagebin.js filename');
